%define anolis_release 1
%global dbus_user_id 81

Name:                 dbus-broker
Version:              35
Release:              %{anolis_release}%{?dist}
Summary:              Linux D-Bus Message Broker
License:              ASL 2.0
URL:                  https://github.com/bus1/%{name}
Source0:              https://github.com/bus1/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
BuildRequires:        gcc glibc-devel meson python3-docutils
BuildRequires:        libselinux-devel systemd-devel systemd
BuildRequires:        audit-libs-devel expat-devel dbus-devel libcap-ng-devel
Requires:             dbus-common
Requires(pre):        shadow-utils

%description
dbus-broker is an implementation of a message bus that follows the D-Bus 
specification. It aims to provide high performance and reliability while 
maintaining compatibility with the D-Bus reference implementation. dbus-broker 
is designed exclusively for Linux systems and makes use of many modern features 
provided by recent Linux kernel releases. It is a useful tool that can help 
improve system performance by providing a reliable and efficient way to 
communicate between processes in a Linux system. dbus-broker can be used for 
various purposes such as system maintenance, backups, and data processing in 
Linux-based systems.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
%meson -Dlinux-4-17=true -Dsystem-console-users=gdm -Ddocs=true -Daudit=true -Dselinux=true
%meson_build

%install
%meson_install

%generate_compatibility_deps

%check
%meson_test

%pre
getent group dbus >/dev/null || groupadd -f -g %{dbus_user_id} -r dbus
if ! getent passwd dbus >/dev/null ; then
    if ! getent passwd %{dbus_user_id} >/dev/null ; then
      useradd -r -u %{dbus_user_id} -g %{dbus_user_id} -d '/' -s /sbin/nologin -c "System message bus" dbus
    else
      useradd -r -g %{dbus_user_id} -d '/' -s /sbin/nologin -c "System message bus" dbus
    fi
fi
exit 0

%post
%systemd_post %{name}.service
%systemd_user_post %{name}.service
%journal_catalog_update

%preun
%systemd_preun %{name}.service
%systemd_user_preun %{name}.service

%postun
%systemd_postun %{name}.service
%systemd_user_postun %{name}.service

%triggerpostun -- dbus-daemon
if [ $2 -eq 0 ] && [ -x /usr/bin/systemctl ] ; then
        systemctl --no-reload          preset %{name}.service || :
        systemctl --no-reload --global preset %{name}.service || :
fi

%files
%dir %{abidir}
%license LICENSE AUTHORS
%{_bindir}/%{name}
%{_bindir}/%{name}-launch
%{abidir}/*.list
%{_journalcatalogdir}/*.catalog
%{_mandir}/man1/%{name}*
%{_unitdir}/%{name}.service
%{_userunitdir}/%{name}.service

%files doc
%doc docs/%{name}.rst docs/%{name}-launch.rst
%doc README.md NEWS.md

%changelog
* Wed Feb 28 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 35-1
- update to 35

* Tue Apr 11 2023 Zhongling <zhonglingh@linux.alibaba.com> - 32-4
- Refactor rpm spec

* Wed Jan 04 2023 happy_orange <songnannan@linux.alibaba.com> -32-3
- add doc package

* Tue Nov 01 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 32-2
- optimise spec file

* Thu Sep 22 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 32-1
- update to 32

* Tue Mar 22 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 29.1
- init from upstream 
